@@ -453,7 +453,16 @@ games_start_server (char *name)
 }
 #endif
 
-#ifdef HAVE_BONJOUR
+#ifdef HAVE_HOWL
+static sw_result
+publish_reply (sw_discovery discovery,
+	       sw_discovery_oid oid,
+	       sw_discovery_publish_status status,
+	       sw_opaque extra)
+{
+  return SW_OKAY;
+}
+#elif defined(HAVE_BONJOUR)
 static void
 publish_reply (DNSServiceRef sdRef,
 	       DNSServiceFlags flags,
@@ -478,14 +487,14 @@ games_host_lan_game (char *name)
         
   if (sw_discovery_init (&discovery) != SW_OKAY) {
     network_gui_message (_("Local Area Network game could not be started. \nTry running mDNSResponder."));
-    g_print ("Failure 4\n");
     return retval;
   }
         
   mtype = g_strdup_printf ("_%s%s", game_port, NETWORK_ZEROCONF_TYPE);
 
   if (!(result = sw_discovery_publish (discovery, 0, name, mtype,
-       NULL, NULL, atoi(game_port), NULL, 0, NULL, NULL, &id)) != SW_OKAY) {
+       NULL, NULL, atoi(game_port), NULL, 0, publish_reply,
+       NULL, &id)) != SW_OKAY) {
     games_start_server (name);
     retval = TRUE;
   }
@@ -652,7 +661,6 @@ games_find_lan_game (void)
 
   if (sw_discovery_init(&discovery) != SW_OKAY) {
     network_gui_message (_("Local Area Network game could not be started. \nTry running mDNSResponder."));
-    g_print ("Failure 1\n");
     return FALSE;
   }
 
@@ -661,7 +669,6 @@ games_find_lan_game (void)
   if (sw_discovery_browse (discovery, 0, mtype, NULL, 
 			  games_browser, NULL, &discovery_oid) != SW_OKAY) {
     network_gui_message (_("Local Area Network game could not be started. \nTry running mDNSResponder."));
-    g_print ("Failure 2\n");
     return FALSE;
   }
 
@@ -690,7 +697,6 @@ games_find_lan_game (void)
 
   if (err != kDNSServiceErr_NoError) {
     network_gui_message (_("Local Area Network game could not be started. \nTry running mDNSResponder."));
-    g_print ("Failure 3\n");
     return FALSE;
   }
 
